@@ -27,11 +27,7 @@ import java.io.InputStream;
 import java.io.UncheckedIOException;
 import java.nio.file.Files;
 import java.nio.file.Path;
-import java.util.ArrayList;
-import java.util.Date;
-import java.util.List;
-import java.util.Optional;
-import java.util.Queue;
+import java.util.*;
 import java.util.function.Function;
 import java.util.logging.Logger;
 
@@ -73,7 +69,7 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
     private InputData inputData;
 
     @ArgGroup(heading = "%nProcessing options:%n")
-    private Processor processor;
+    private Processor processor = new Processor();
     
     @ArgGroup(heading = "%nGeneral overrides:%n", exclusive = false)
     private Overrides overrides = new Overrides();
@@ -86,12 +82,32 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
 
     @Override
     public int handleCommand() throws Exception {
+        final int MAX_ADDRESS = 0xFFFF;
+        final int MAX_AUXTYPE = 0xFFFF;
+
+        if (overrides.fileAddress.isPresent()){
+            final int fileAddress = overrides.fileAddress.get();
+            if (fileAddress < 0 || fileAddress > MAX_ADDRESS) {
+                String errormsg = String.format("address(%d) is out of range(0-%d).", fileAddress, MAX_ADDRESS);
+                throw new IllegalArgumentException(errormsg);
+            }
+        }
+
+       if (overrides.auxType.isPresent()){
+            final int auxType = overrides.auxType.get();
+            if (auxType < 0 || auxType > MAX_AUXTYPE) {
+                String errormsg = String.format("auxiliary type(%d) is out of range(0-%d).", auxType, MAX_AUXTYPE);
+                throw new IllegalArgumentException(errormsg);
+            }
+        }
+
         DirectoryEntry directory = disk.getFormattedDisks()[0];
         if (directoryName.isPresent()) {
             String[] dirs = directoryName.get().split("/");
             for (String dir : dirs) {
                 Optional<FileEntry> fileEntry = directory.getFiles().stream()
                         .filter(f -> dir.equalsIgnoreCase(f.getFilename()))
+                        .filter(f -> !f.isDeleted())
                         .findFirst();
                 Optional<DirectoryEntry> dirEntry = fileEntry
                         .filter(FileEntry::isDirectory)
@@ -153,14 +169,19 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
             }
         }
     }
-    
+
     public static class Processor {
-        private Function<FileEntryReader,List<FileEntryReader>> fileEntryReaderFn;
-        
+        private Function<FileEntryReader,List<FileEntryReader>> fileEntryReaderFn = this::handleRawFile;
+
         public List<FileEntryReader> apply(FileEntryReader reader) {
             return fileEntryReaderFn.apply(reader);
         }
-        
+
+        @Option(names = { "--raw", "--binary" }, description = { "Import as a raw binary file." })
+        public void setRawBinaryMode(boolean flag) {
+            fileEntryReaderFn = this::handleRawFile;
+        }
+
         @Option(names = { "--text", "--text-high" }, description = { 
                 "Import as a text file, setting high bit and ",
                 "replacing newline characters with $8D." })
@@ -201,6 +222,10 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
             fileEntryReaderFn = this::handleShrinkitMode;
         }
 
+        private List<FileEntryReader> handleRawFile(FileEntryReader reader) {
+            return Arrays.asList(reader);
+        }
+
         private List<FileEntryReader> handleTextModeSetHighBit(FileEntryReader reader) {
             InputStream inputStream = new ByteArrayInputStream(reader.getFileData().get());
             return handleTextMode(TranslatorStream.builder(inputStream)
@@ -281,13 +306,16 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
                 }
                 ProdosFileInfo info = as.getProdosFileInfo();
                 String fileType = ProdosFormatDisk.getFiletype(info.getFileType());
-                
+
                 OverrideFileEntryReader.Builder builder = OverrideFileEntryReader.builder();
                 builder.filename(Optional.ofNullable(as.getRealName()));
+                builder.prodosFiletype(fileType);
+                builder.locked((info.getAccess()&0xc2) != 0xc2); //Unlocked if destroy, rename and write are all enabled
                 builder.fileData(as.getDataFork());
                 builder.resourceData(Optional.ofNullable(as.getResourceFork()));
-                builder.prodosFiletype(fileType);
-                builder.locked(info.getAccess() == 0xc3);
+                if (ProdosFormatDisk.fileTypeNeedsAddress(fileType)) {
+                    builder.binaryAddress(info.getAuxType());
+                }
                 builder.auxiliaryType(info.getAuxType());
                 
                 if (as.getFileDatesInfo() != null) {
@@ -350,7 +378,8 @@ public class ImportCommand extends ReadWriteDiskCommandOptions {
         private Optional<String> fileName;
         
         @Option(names = { "--aux", "--auxtype" }, description = "Aux. Type. "
-                + "(For a filesystem that supports aux type.)")
+                + "(For a filesystem that supports aux type.)",
+                converter = IntegerTypeConverter.class)
         private Optional<Integer> auxType;
     }
 }
