@@ -19,27 +19,15 @@
  */
 package com.webcodepro.applecommander.storage.os.prodos;
 
-import java.io.IOException;
-import java.io.InputStream;
-import java.util.ArrayList;
-import java.util.Date;
-import java.util.List;
-import java.util.Properties;
-import java.util.Set;
-import java.util.HashSet;
-
-import com.webcodepro.applecommander.storage.DirectoryEntry;
-import com.webcodepro.applecommander.storage.DiskException;
-import com.webcodepro.applecommander.storage.DiskCorruptException;
-import com.webcodepro.applecommander.storage.DiskFullException;
-import com.webcodepro.applecommander.storage.DiskGeometry;
-import com.webcodepro.applecommander.storage.FileEntry;
-import com.webcodepro.applecommander.storage.FormattedDisk;
-import com.webcodepro.applecommander.storage.StorageBundle;
+import com.webcodepro.applecommander.storage.*;
 import com.webcodepro.applecommander.storage.physical.ImageOrder;
 import com.webcodepro.applecommander.util.AppleUtil;
 import com.webcodepro.applecommander.util.TextBundle;
 
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.*;
+
 /**
  * Manages a disk that is in the ProDOS format.
  * <p>
@@ -1286,7 +1274,7 @@ public class ProdosFormatDisk extends FormattedDisk {
 	/**
 	 * Locate the associated ProdosFileType.
 	 */
-	public static ProdosFileType findFileType(String filetype) {
+	static ProdosFileType findFileType(String filetype) {
 		for (int i=0; i<fileTypes.length; i++) {
 			if (filetype.equalsIgnoreCase(fileTypes[i].getString())) {
 				return fileTypes[i];
@@ -1295,6 +1283,17 @@ public class ProdosFormatDisk extends FormattedDisk {
 		return null;
 	}
 
+	/**
+	 * Utility method to indicate if this file type needs an address.
+	 */
+	public static boolean fileTypeNeedsAddress(String filetype) {
+		ProdosFileType prodosFileType = findFileType(filetype);
+		if (prodosFileType != null) {
+			return prodosFileType.needsAddress();
+		}
+		return false;
+	}
+
 	/**
 	 * Returns a list of possible file types.  Since the filetype is
 	 * specific to each operating system, a simple String is used.
@@ -1458,4 +1457,21 @@ public class ProdosFormatDisk extends FormattedDisk {
     public DiskGeometry getDiskGeometry() {
         return DiskGeometry.BLOCK;
     }
+
+	/**
+	 * Provides conversation from a given ProDOS file type since as it is common across
+	 * many archiving tools.
+	 */
+	@Override
+	public String fromProdosFiletype(String prodosFiletype) {
+		return prodosFiletype;
+	};
+	/**
+	 * Provides conversation to a given ProDOS file type since as it is common across
+	 * many archiving tools.
+	 */
+	@Override
+	public String toProdosFiletype(String nativeFiletype) {
+		return nativeFiletype;
+	};
 }
